#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
utils functions related to paper
"""


def inlog(paper_id: str):
    """[summary]

    Args:
        paper_id (str): [description]

    Returns:
        [type]: [description]
    """
    return False


def write_paper_log(fields: dict):
    """[summary]

    Args:
        fields (dict): [description]
    """
    pass


def read_paper_log(paper_id: str):
    """[summary]

    Args:
        paper_id (str): [description]

    Returns:
        [type]: [description]
    """
    return None


def remove_paper_log(paper_id: str):
    """[summary]

    Args:
        paper_id (str): [description]
    """
    pass


def parse_authors(authors_string: str):
    """[summary]

    Args:
        authors_string (str): [description]
    """
    return []
